extern crate chrono;
#[macro_use] extern crate rocket;

use std::fs::OpenOptions;
use std::io::Write;

use chrono::Local;
use rocket::form::Form;
use rocket::fs::FileServer;
use rocket::response::content::RawHtml;

fn get(show_thank_you: bool) -> RawHtml<String> {
    let message = if show_thank_you {
        "<p>Message Received!</p>"
    } else {
        ""
    };
    RawHtml(
    format!(r###"<!DOCTYPE html>
<html>
  <head>
    <title>Message Sage 😎</title>
    <link rel='stylesheet' href='/static/style.css' />
    <meta name=viewport content="width=device-width,minimum-scale=1">
  </head>
  <body>
    <div id="main" style="margin-left: auto; margin-right: auto; display: flex; flex-direction: column">
      <h1>Message Sage 😎</h1>
      <form method="POST" style="display: flex; flex-direction: column">
        <label for="message" style="margin-bottom: 1em;">What did you want to say?</label>
        <input id="message" name="message" type="text" style="margin-bottom: 1em;">
        <button type="submit">Submit</button>
      </form>
      {message}

    </div>
  </body>
</html>
    "###))
}

#[get("/")]
fn index() -> RawHtml<String> {
    get(false)
}

#[derive(FromForm)]
struct MessagePost<'r> {
    message: &'r str
}

#[post("/", data = "<message>")]
fn message<'r>(message: Form<MessagePost<'r>>) -> Result<RawHtml<String>, std::io::Error> {
    let mut file = OpenOptions::new()
        .create(true)
        .append(true)
        .open("messages.log")
        .unwrap();
    let now = Local::now();
    writeln!(&mut file, "{} {}", now.format("[%Y-%m-%d %H:%M:%S]"), message.message)?;
    Ok(get(true))
}

#[launch]
fn rocket() -> _ {
    rocket::build()
        .mount("/static", FileServer::from("./static"))
        .mount("/", routes![index, message])
}

